import LimitedArray from "./LimitedArray.js";
import Task from "./Task.js";
import Log from './Log.js'

export default class Cache {

    static create(key) {
        return new Cache(key)
    }

    constructor(cacheKey) {
        this.key = cacheKey;
        this.storage = new Map();
        this.keysArray = new LimitedArray(999_999_999);

        this._seconds = null;
        this._limit = null;
    }

    get(key) {
        const value = this.storage.get(key);
        if (value) {
            Log.debug(`Using '${this.key}' cache`);
        }
        return value;
    }

    add(key, value) {
        const existingValue = this.get(key);
        if (!existingValue) {
            this.keysArray.add(key);
            Log.debug(`Adding to '${this.key}' cache`);
            this._deleteIfLastRemoved();
        }
        this.storage.set(key, value);
    }

    limit(limit) {
        this._limit = limit;
        this.keysArray.limit = limit;
        return this;
    }

    hours(hours) {
        return this.minutes(hours * 60);
    }

    minutes(minutes) {
        return this.seconds(minutes * 60)
    }

    seconds(seconds) {
        return this._clearSeconds(seconds);
    }

    milliseconds(milliseconds) {
        const seconds = Math.round(milliseconds / 1000);
        return this._clearSeconds(seconds);
    }

    information() {
        let info = `Cache '${this.key}'`;
        if (this._limit) {
            info += `, Limit: ${this._limit}`;
        }
        if (this._seconds) {
            info += `, Clear every: ${this._seconds} seconds`;
        }
        return info;
    }

    _deleteIfLastRemoved() {
        const lastRemovedKey = this.keysArray.getLastRemoved();
        if (this._limit && lastRemovedKey) {
            this.storage.delete(lastRemovedKey);
        }
    }

    _clearCache() {
        this.storage.clear();
        this.keysArray.clear();
    }

    _clearSeconds(seconds) {
        this._seconds = seconds;
        Task.do(() => {
            Log.debug(`Clearing ${this.key} caches...`);
            this._clearCache();
        }).every(seconds);
        return this;
    }

}