import Language from "./Language.js";

export default class DateUtil {

  static SECOND = 1000;
  static MINUTE = 60 * 1000;
  static HOUR = 60 * 60 * 1000;
  static DAY = 24 * 60 * 60 * 1000;

  static WEEK = 7 * 24 * 60 * 60 * 1000;
  static THIRTY_DAYS = 30 * 24 * 60 * 60 * 1000;
  static NINETY_DAYS = 90 * 24 * 60 * 60 * 1000;
  static YEAR = 365 * 24 * 60 * 60 * 1000;

  static now(milliseconds = 0) {
    const date = new Date();
    date.setTime(date.getTime() - milliseconds);
    return date;
  }

  static onlyDate(date = this.now()) {
    return date
      .toISOString()
      .slice(0, 10);
  }

  static hoursAgo(hours = 1) {
    return this.now(hours * this.HOUR);
  }

  static oneHourAgo() {
    return this.hoursAgo();
  }

  static twoHourAgo() {
    return this.hoursAgo(2);
  }

  static threeHourAgo() {
    return this.hoursAgo(3);
  }

  static sixHourAgo() {
    return this.hoursAgo(6);
  }

  static twelveHourAgo() {
    return this.hoursAgo(12);
  }

  static prevMonth() {
    return this.now(this.THIRTY_DAYS);
  }

  static oneMonthAgo() {
    return this.prevMonth();
  }

  static threeMonthsAgo() {
    return this.now(this.NINETY_DAYS);
  }

  static yesterday() {
    return this.now(this.DAY);
  }

  static toLocaleString(date, languageCode) {
    return date.toLocaleString(languageCode, { timeZone: 'UTC' });
  }

  static monthsToYears(months) {
    return Math.floor(months / 12);
  }

  static getLocaleFromLanguageCode(languageCode) {
    switch (languageCode) {
      case Language.SPANISH:
        return 'es-ES';
      case Language.ENGLISH: default:
        return 'en-US';
    }
  }

  static difference(endDate, startDate) {
    return new Date(endDate - startDate);
  }

  static monthDifference(firstDate, lastDate) {
    let months;
    months = (lastDate.getFullYear() - firstDate.getFullYear()) * 12;
    months -= firstDate.getMonth();
    months += lastDate.getMonth();
    return months <= 0 ? 0 : months;
  }

  static isSameDay(firstDate, secondDate) {
    return firstDate.getDate() === secondDate.getDate()
      && firstDate.getMonth() === secondDate.getMonth()
      && firstDate.getFullYear() === secondDate.getFullYear();
  }

  static isToday(date) {
    return this.isSameDay(this.now(), date);
  }

  // TODO: Those below method can be mover to another file.
  static millisecondsToMS(milliseconds) {
    const time = this.convertMiliseconds(milliseconds);
    return `${this.addZero(time.minutes)}:${this.addZero(time.seconds)}`;
  }

  static millisecondsToMSMs(milliseconds) {
    const time = this.convertMiliseconds(milliseconds);
    return `${this.addZero(time.minutes)}:${this.addZero(time.seconds)}.${time.milliseconds}`;
  }

  static millisecondsToDHMS(milliseconds) {
    const time = this.convertMiliseconds(milliseconds);
    return `${this.addZero(time.days)}:${this.addZero(time.hours)}:${this.addZero(time.minutes)}:${this.addZero(time.seconds)}`;
  }

  static convertMiliseconds(totalMilliseconds, format) {
    let days, hours, minutes, seconds, milliseconds,
      total_hours, total_minutes, total_seconds;

    total_seconds = parseFloat(totalMilliseconds / 1000);
    total_minutes = parseInt(Math.floor(total_seconds / 60));
    total_hours = parseInt(Math.floor(total_minutes / 60));
    days = parseInt(Math.floor(total_hours / 24));

    seconds = parseInt(total_seconds % 60);
    milliseconds = parseInt(Math.round((total_seconds - seconds) * 1000));
    minutes = parseInt(total_minutes % 60);
    hours = parseInt(total_hours % 24);

    switch (format) {
      case 's':
        return total_seconds;
      case 'm':
        return total_minutes;
      case 'h':
        return total_hours;
      case 'd':
        return days;
      default:
        return { days: days, hours: hours, minutes: minutes, seconds: seconds, milliseconds: milliseconds };
    }
  }

  static addZero(number) {
    const formattedNumber = number.toString();
    if (formattedNumber.length === 1) {
      return `0${formattedNumber}`;
    }
    return formattedNumber;
  }

}
