import Language from "./Language.js";
import PropertiesFileReader from "./PropertiesFileReader.js";
import StringTemplateReplacer from "./StringTemplateReplacer.js";

export default class Message {

    static DEFAULT_LANGAUGE = Language.ENGLISH;
    static SUPPORTED_LANGUAGES = [];
    static LANGUAGES = new Map();

    static init(path) {
        for (const language of this.SUPPORTED_LANGUAGES) {
            const filePath = `${path}/${language}.properties`;
            this.LANGUAGES.set(language, new PropertiesFileReader(filePath));
        }
    }

    static get(languageCode = this.DEFAULT_LANGAUGE, key, ...values) {
        const language = this.LANGUAGES.get(languageCode);
        let propertiesText = language.get(key);

        if (!propertiesText && languageCode !== this.DEFAULT_LANGAUGE) {
            return this.get(this.DEFAULT_LANGAUGE, key, values);
        } else if (!propertiesText) {
            return key;
        }

        propertiesText = StringTemplateReplacer.replace(propertiesText, ...values);
        propertiesText = StringTemplateReplacer.replaceLineBreaks(propertiesText);
        return propertiesText;
    }
}
