import MathUtil from './MathUtil.js';
import StringReplacer from './StringReplacer.js';

export default class NumberExtractor {

    static NUMBER_REGEX = /\d*[,|.]?\d+[,|.]\d+|\d+/;
    static DO_NOT_REPLACE_TEXT = `DO_NOT_REPLACE`;

    static fromString(string) {
        const regexValues = this.NUMBER_REGEX.exec(string);
        if (!regexValues) return null;

        let numberString = regexValues[0];
        numberString = this.correctDecimalSeparators(numberString);
        let number = Number(numberString.trim()); 
        
        const multiplier = this.extractMultiplier(string);
        number = MathUtil.multiplyNumber(number, multiplier);
        
        return number;
    }

    static extractMultiplier(string) {
        const regexValues = this.NUMBER_REGEX.exec(string);
        if (!regexValues) return null;

        const numberString = regexValues[0];
        const startIndex = string.indexOf(numberString) + numberString.length;
        const multiplier = string.substr(startIndex, 1);
        if (multiplier === 'K' || multiplier === 'k') { 
            return multiplier;
        }
        return null;
    }

    static correctDecimalSeparators(numberString){
        if (!numberString.includes(',')) {
            numberString = StringReplacer.replaceIndexBy(numberString, numberString.lastIndexOf(`.`), this.DO_NOT_REPLACE_TEXT);
            numberString = numberString.replaceAll(`.`, ``);

            const lastNumbers = numberString.substr(numberString.indexOf(this.DO_NOT_REPLACE_TEXT) + this.DO_NOT_REPLACE_TEXT.length);
            if (lastNumbers.length === 3) {
                numberString = numberString.replace(this.DO_NOT_REPLACE_TEXT, ``);
                return numberString;    
            }
            numberString = numberString.replace(this.DO_NOT_REPLACE_TEXT, `.`);
            return numberString; 
        };

        numberString = numberString.replaceAll(`.`, `,`);
        numberString = StringReplacer.replaceIndexBy(numberString, numberString.lastIndexOf(`,`), `.`);
        numberString = numberString.replaceAll(`,`, '');
        return numberString;
    }

}