export default class ObjectComparer {

    static compare(object1, object2) {
        if (this._areEasyComparable(object1, object2)) {
            return object1 === object2;
        }

        if (this._areDates(object1, object2)) {
            return this._compareDates(object1, object2);
        }

        if (this._areObjects(object1, object2)) {
            return this._compareObjects(object1, object2);
        }

        if (this._areArrays(object1, object2)) {
            return this._compareArrays(object1, object2);
        }

        return false;
    }

    static _compareArrays(array1, array2) {
        if (array1.length !== array2.length) {
            return false;
        }
        array1 = array1.sort();
        array2 = array2.sort();

        for (let index = 0; index < array1.length; index++) {
            const object1 = array1[index];
            const object2 = array2[index];

            const isSame = this.compare(object1, object2)
            if (!isSame) {
                return false;
            }
        }
        return true;
    }

    static _compareObjects(object1, object2) {
        const object1Map = new Map(Object.entries(object1));
        const object2Map = new Map(Object.entries(object2));

        for (const key of object1Map.keys()) {
            const value1 = object1Map.get(key);
            const value2 = object2Map.get(key);

            if (!value2) {
                return false;
            }

            const isSame = this.compare(value1, value2);
            if (!isSame) {
                return false;
            }
        }
        return true;
    }

    static _areEasyComparable(object1, object2) {
        return this._isEasyComparable(object1)
            && this._isEasyComparable(object2);
    }

    static _isEasyComparable(object) {
        return typeof object === "boolean"
            || typeof object === "string"
            || typeof object === "number";
    }

    static _areObjects(object1, object2) {
        return this._isObject(object1) && this._isObject(object2);
    }

    static _isObject(object) {
        return typeof object === "object" && !object.length;
    }

    static _areDates(object1, object2) {
        return this._isDate(object1) && this._isDate(object2);
    }

    static _isDate(object) {
        return object instanceof Date;
    }

    static _compareDates(date1, date2) {
        return date1.toString() === date2.toString();
    }

    static _areArrays(object1, object2) {
        return this._isArray(object1) && this._isArray(object2);
    }

    static _isArray(object) {
        return object instanceof Array || (typeof object === "object"
            && object.length !== undefined);
    }

}