import fs from 'fs';

export default class PropertiesFileReader {

  constructor(filepath) {
    this.data = fs.readFileSync(filepath).toString();
    this.properties = new Map();

    const lines = this.data.split('\n');
    let currentKey, currentText = '';
    for (const line of lines) {
      if (this._lineContainsKey(line)) {
        this._saveProperty(currentKey, currentText);

        const separatedLine = line.split('=');
        currentKey = separatedLine[0];
        currentText = separatedLine[1];

        if (line === lines[lines.length - 1]) {
          this._saveProperty(currentKey, currentText);
        }
      } else if (this._shouldContinue(line)) {
        continue;
      } else {
        currentText += line;
      }
    }
  }

  get(key) {
    return this.properties.get(key);
  }

  _lineContainsKey(line) {
    return line.includes('=');
  }

  _shouldContinue(line) {
    return !line
      || line === ''
      || line.includes('#');
  }

  _saveProperty(key, text) {
    if (!key || !text) return;
    this.properties.set(key, text);
  }

}
