import assert from 'assert';
import LimitedArray from '../src/LimitedArray.js';

describe('LimitedArray.js', function () {

    describe('#add(item)', function () {

        it('should add item correctly', function () {
            var array = new LimitedArray();
            var item = 3;

            var expected = 1;
            var result = array.add(item)._size();

            assert.deepStrictEqual(result, expected);
        });

        it('should respect default limit correctly', function () {
            var array = new LimitedArray();
            array.add(5);
            array.add(2);

            var expected = 1;
            var result = array._size();

            assert.deepStrictEqual(result, expected);
        });

        it('should respect custom limit correctly', function () {
            var array = new LimitedArray(3);
            array.add(5);
            array.add(2);
            array.add(6);
            array.add(9);

            var expected = 3;
            var result = array._size();

            assert.deepStrictEqual(result, expected);
        });

    });

    describe('#addMultiple(items)', function () {

        it('should add items correctly', function () {
            var array = new LimitedArray(2);
            var items = [3, 5];

            var expected = 2;
            var result = array.addMultiple(items)._size();

            assert.deepStrictEqual(result, expected);
        });

        it('should respect custom limit correctly', function () {
            var array = new LimitedArray(3);
            var items = [3, 5, 8, 10];

            var expected = 3;
            var result = array.addMultiple(items)._size();

            assert.deepStrictEqual(result, expected);
        });

    });

    describe('#result()', function () {

        it('should remove the last', function () {
            var array = new LimitedArray(2);
            var lastShould = 5;
            var firstShould = 10;
            var items = [3, lastShould];
            array.addMultiple(items);
            array.add(firstShould);

            var arrayResult = array.result();

            var expected = lastShould;
            var result = arrayResult[1];
            assert.deepStrictEqual(result, expected);

            var expected = firstShould;
            var result = arrayResult[0];
            assert.deepStrictEqual(result, expected);
        });

    });

});
