import assert from 'assert';
import MathUtil from '../src/MathUtil.js';

describe('MathUtil.js', function () {

    describe('#average(values)', function () {

        it('should return 0 if there values are null', function () {
            var values = null;

            var expected = 0;
            var result = MathUtil.average(values);
            assert.deepStrictEqual(result, expected);
        });

        it('should return 0 if there values are empty', function () {
            var values = [];

            var expected = 0;
            var result = MathUtil.average(values);
            assert.deepStrictEqual(result, expected);
        });

        it('should return the same value is there is only one value', function () {
            var values = [2];

            var expected = 2;
            var result = MathUtil.average(values);
            assert.deepStrictEqual(result, expected);
        });

        it('should return the correct average with three values', function () {
            var values = [5, 10, 15];

            var expected = 10;
            var result = MathUtil.average(values);
            assert.deepStrictEqual(result, expected);
        });

    });

    describe('#multiplyNumber(number, multiplier)', function () {
        it('should return same number when multiplier is not supported', function () {
            var number = 10;

            var expected = number;
            var result = MathUtil.multiplyNumber(number, 'noSupported');

            assert.deepStrictEqual(result, expected);
        });

        it('should return thousand number (number * 1000) when the when multiplier is for thousands', function () {
            var number = 10;

            var expected = 10_000;
            var result = MathUtil.multiplyNumber(number, 'k');

            assert.deepStrictEqual(result, expected);
        });
    });

    describe('#differencePercentage(number1, number2)', function () {
        it('should return 0 when the numbers are equal', function () {
            var number1 = 20;
            var number2 = 20;

            var expected = 0;
            var result = MathUtil.differencePercentage(number1, number2);

            assert.deepStrictEqual(result, expected);
        });

        it('should return -20 when the number1 (new) is 25 and number2 is 20 (old)', function () {
            var number1 = 25;
            var number2 = 20;

            var expected = -20;
            var result = MathUtil.differencePercentage(number1, number2);

            assert.deepStrictEqual(result, expected);
        });
    });

    describe('#isPositive(number)', function () {
        it('should return true when the number is positive', function () {
            var mockData = 2;

            var expected = true;
            var result = MathUtil.isPositive(mockData);

            assert.deepStrictEqual(result, expected);
        });

        it('should return false when the number is negative', function () {
            var mockData = -2.3;

            var expected = false;
            var result = MathUtil.isPositive(mockData);

            assert.deepStrictEqual(result, expected);
        });
    });

    describe('#isNegative(number)', function () {
        it('should return true when the number is positive', function () {
            var mockData = 8;

            var expected = false;
            var result = MathUtil.isNegative(mockData);

            assert.deepStrictEqual(result, expected);
        });

        it('should return false when the number is negative', function () {
            var mockData = -5;

            var expected = true;
            var result = MathUtil.isNegative(mockData);

            assert.deepStrictEqual(result, expected);
        });
    });

});
