import assert from 'assert';
import NumberExtractor from '../src/NumberExtractor.js';

describe('NumberExtractor.js', function () {
  
    describe('#fromString(string)', function () {
        
        it('should return null if there is no number in the string', function () {
            var string = "hello world";

            var expected = null;
            var result = NumberExtractor.fromString(string);

            assert.deepStrictEqual(result, expected);
        });

        it('should return the number for normal cases', function () {
            var string = "hello54world";

            var expected = 54;
            var result = NumberExtractor.fromString(string);

            assert.deepStrictEqual(result, expected);
        });

        it('should return the number for larger cases', function () {
            var string = "this is a large text which has the number 355 written on it.";

            var expected = 355;
            var result = NumberExtractor.fromString(string);

            assert.deepStrictEqual(result, expected);
        });

        it('should return the number for decimal and thousand separator', function () {
            var string = "the price is: 1.000,23$";

            var expected = 1_000.23;
            var result = NumberExtractor.fromString(string);

            assert.deepStrictEqual(result, expected);
        });

        it('should return the number for thousand separator', function () {
            var string = "the price is: 1.000.000$";

            var expected = 1_000_000;
            var result = NumberExtractor.fromString(string);

            assert.deepStrictEqual(result, expected);
        });

        it('should return the number for decimal separator', function () {
            var string = "the price is: 12,15$";

            var expected = 12.15;
            var result = NumberExtractor.fromString(string);

            assert.deepStrictEqual(result, expected);
        });

        it('should return the correct number having thousand multiplier', function () {
            var string = "Visitas: 1.5k";

            var expected = 1500;
            var result = NumberExtractor.fromString(string);

            assert.deepStrictEqual(result, expected);
        });

        it('should return the correct number for millions having dot separator', function () {
            var string = "Price is: 100.000.000€";

            var expected = 100_000_000;
            var result = NumberExtractor.fromString(string);

            assert.deepStrictEqual(result, expected);
        });

    });

    describe('#extractMultiplier(string)', function () {
        
        it('should return null if there is no number in the string', function () {
            var string = "hello world";

            var expected = null;
            var result = NumberExtractor.extractMultiplier(string);

            assert.deepStrictEqual(result, expected);
        });

        it('should return null if there is a number but without multiplier', function () {
            var string = "hello54world";

            var expected = null;
            var result = NumberExtractor.extractMultiplier(string);

            assert.deepStrictEqual(result, expected);
        });

        it('should return thousand multiplier if there is a number with a multiplier', function () {
            var string = "this cost at least: 300k per item";

            var expected = 'k';
            var result = NumberExtractor.extractMultiplier(string);

            assert.deepStrictEqual(result, expected);
        });

    });

    describe('#correctDecimalSeparators(numberString)', function () {
        
        it('should return same number if its properly formatted', function () {
            var numberString = "10,25";

            var expected = "10.25";
            var result = NumberExtractor.correctDecimalSeparators(numberString);

            assert.deepStrictEqual(result, expected);
        });

        it('should return number properly formatted', function () {
            var numberString = "100.000,23";

            var expected = "100000.23";
            var result = NumberExtractor.correctDecimalSeparators(numberString);

            assert.deepStrictEqual(result, expected);
        });

    });
  
});
